events
======

.. automodule:: pyramid_fullauth.events


    Registration
    ------------


    .. autoclass:: BeforeRegister


    .. autoclass:: AfterRegister


    Account activation
    ------------------


    .. autoclass:: AfterActivate


    Password reset
    --------------

    .. autoclass:: AfterResetRequest


    .. autoclass:: AfterReset


    Login
    -----


    .. autoclass:: AlreadyLoggedIn


    .. autoclass:: BeforeLogIn


    .. autoclass:: AfterLogIn


    Social registration/login
    -------------------------

    .. autoclass:: BeforeSocialRegister


    .. autoclass:: AfterSocialRegister


    .. autoclass:: AfterSocialLogIn


    .. autoclass:: SocialAccountAlreadyConnected
